# J.COp ML
J.COp ML is a machine Learning package to complement scikit-learn workflow. It includes helper functions for visualization, tuning, pipeline, and feature importance.

The project started in July 2018 as a tool to teach machine learning for beginner, but the serious development began in March 2019 together with the initiation of the LuWiji project. Both LuWiji and J.COp ML is developed by Wira D. K. Putra as complementary for his machine learning curriculum for young machine learning enthusiast.

# User Installation Guide
```
pip install jcopml
```